pub enum WebsocketSupportedExchanges {
Hyperliquid,
ByBit,
Kraken,
Binance,
Okx,
KuCoin,
Bitget,
Coinbase,
Aster,
Pacifica,
Lighter,
Paradex,
}Variants
Implementations
Sourceimpl WebsocketSupportedExchanges
impl WebsocketSupportedExchanges
pub fn ping(&self) -> String
pub fn depth(&self, coin: &str) -> String
pub fn trades(&self, coin: &str) -> String
pub fn candle(&self, coin: &str) -> Option<String>
Sourcepub fn batch_depth(&self, coins: &[String]) -> Option<String>
pub fn batch_depth(&self, coins: &[String]) -> Option<String>
Subscribe to depth for multiple symbols in a single message (Binance only) Other exchanges don’t support batching and will return None
Sourcepub fn batch_trades(&self, coins: &[String]) -> Option<String>
pub fn batch_trades(&self, coins: &[String]) -> Option<String>
Subscribe to trades for multiple symbols in a single message (Binance only) Other exchanges don’t support batching and will return None
Sourcepub fn websocket_url(&self) -> &'static str
pub fn websocket_url(&self) -> &'static str
Get the websocket URL for this exchange.
Note: KuCoin requires a short-lived token appended as a query parameter.
Use KuCoinClient::get_ws_url() to obtain the full authenticated URL.
The value returned here is the base server endpoint without a token.
Sourcepub fn default_ping_interval(&self) -> u64
pub fn default_ping_interval(&self) -> u64
Get the default ping interval in seconds for this exchange
Sourcepub fn default_ping_timeout(&self) -> u64
pub fn default_ping_timeout(&self) -> u64
Get the default ping timeout in seconds for this exchange
Sourcepub fn default_reconnect_timeout(&self) -> u64
pub fn default_reconnect_timeout(&self) -> u64
Get the default reconnect timeout in milliseconds for this exchange